package com.sundot.airport.personnel.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.sundot.airport.personnel.domain.PersonnelNonCadreMonthlyAssessment;

/**
 * 非干部月度考核Service接口
 *
 * @author ruoyi
 * @date 2026-05-07
 */
public interface IPersonnelNonCadreMonthlyAssessmentService extends IService<PersonnelNonCadreMonthlyAssessment> {
    /**
     * 查询非干部月度考核
     *
     * @param id 非干部月度考核主键
     * @return 非干部月度考核
     */
    public PersonnelNonCadreMonthlyAssessment selectPersonnelNonCadreMonthlyAssessmentById(Long id);

    /**
     * 查询非干部月度考核列表
     *
     * @param personnelNonCadreMonthlyAssessment 非干部月度考核
     * @return 非干部月度考核集合
     */
    public List<PersonnelNonCadreMonthlyAssessment> selectPersonnelNonCadreMonthlyAssessmentList(PersonnelNonCadreMonthlyAssessment personnelNonCadreMonthlyAssessment);

    /**
     * 新增非干部月度考核
     *
     * @param personnelNonCadreMonthlyAssessment 非干部月度考核
     * @return 结果
     */
    public int insertPersonnelNonCadreMonthlyAssessment(PersonnelNonCadreMonthlyAssessment personnelNonCadreMonthlyAssessment);

    /**
     * 修改非干部月度考核
     *
     * @param personnelNonCadreMonthlyAssessment 非干部月度考核
     * @return 结果
     */
    public int updatePersonnelNonCadreMonthlyAssessment(PersonnelNonCadreMonthlyAssessment personnelNonCadreMonthlyAssessment);

    /**
     * 批量删除非干部月度考核
     *
     * @param ids 需要删除的非干部月度考核主键集合
     * @return 结果
     */
    public int deletePersonnelNonCadreMonthlyAssessmentByIds(Long[] ids);

    /**
     * 删除非干部月度考核信息
     *
     * @param id 非干部月度考核主键
     * @return 结果
     */
    public int deletePersonnelNonCadreMonthlyAssessmentById(Long id);

    /**
     * 完善数据
     *
     * @param personnelNonCadreMonthlyAssessment 完善数据
     * @return 完善数据
     */
    public void doImprove(PersonnelNonCadreMonthlyAssessment personnelNonCadreMonthlyAssessment);

    /**
     * 修改非干部月度考核-仅更新主表数据
     *
     * @param personnelNonCadreMonthlyAssessment 非干部月度考核
     * @return 结果
     */
    public int updatePersonnelNonCadreMonthlyAssessmentOnly(PersonnelNonCadreMonthlyAssessment personnelNonCadreMonthlyAssessment);

    /**
     * 自动生成指定月份非干部月度考核
     *
     * @param month 月份值
     * @return 结果
     */
    public List<PersonnelNonCadreMonthlyAssessment> autoGenerate(String month);
}
